@@ -2,7 +2,6 @@
 package client
 
 import (
-	"errors"
 	"fmt"
 	"os"
 
@@ -13,6 +12,9 @@ import (
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
 
+// ErrNotImplemented is returned when a client does not implement certain feature.
+var ErrNotImplemented = fmt.Errorf("not implemented")
+
 // Info of the repository.
 type Info struct {
 	Description string
@@ -21,8 +23,9 @@ type Info struct {
 }
 
 type Repo struct {
-	Owner string
-	Name  string
+	Owner  string
+	Name   string
+	Branch string
 }
 
 func (r Repo) String() string {
@@ -39,6 +42,8 @@ type Client interface {
 	ReleaseURLTemplate(ctx *context.Context) (string, error)
 	CreateFile(ctx *context.Context, commitAuthor config.CommitAuthor, repo Repo, content []byte, path, message string) (err error)
 	Upload(ctx *context.Context, releaseID string, artifact *artifact.Artifact, file *os.File) (err error)
+	GetDefaultBranch(ctx *context.Context, repo Repo) (string, error)
+	Changelog(ctx *context.Context, repo Repo, prev, current string) (string, error)
 }
 
 // New creates a new client depending on the token type.
@@ -48,16 +53,16 @@ func New(ctx *context.Context) (Client, error) {
 
 func newWithToken(ctx *context.Context, token string) (Client, error) {
 	log.WithField("type", ctx.TokenType).Debug("token type")
-	if ctx.TokenType == context.TokenTypeGitHub {
+	switch ctx.TokenType {
+	case context.TokenTypeGitHub:
 		return NewGitHub(ctx, token)
-	}
-	if ctx.TokenType == context.TokenTypeGitLab {
+	case context.TokenTypeGitLab:
 		return NewGitLab(ctx, token)
-	}
-	if ctx.TokenType == context.TokenTypeGitea {
+	case context.TokenTypeGitea:
 		return NewGitea(ctx, token)
+	default:
+		return nil, fmt.Errorf("invalid client token type: %q", ctx.TokenType)
 	}
-	return nil, fmt.Errorf("invalid client token type: %q", ctx.TokenType)
 }
 
 func NewIfToken(ctx *context.Context, cli Client, token string) (Client, error) {
@@ -89,18 +94,3 @@ type RetriableError struct {
 func (e RetriableError) Error() string {
 	return e.Err.Error()
 }
-
-// NotImplementedError happens when trying to use something a client does not
-// implement.
-type NotImplementedError struct {
-	TokenType context.TokenType
-}
-
-func (e NotImplementedError) Error() string {
-	return fmt.Sprintf("not implemented for %s", e.TokenType)
-}
-
-// IsNotImplementedErr returns true if given error is a NotImplementedError.
-func IsNotImplementedErr(err error) bool {
-	return errors.As(err, &NotImplementedError{})
-}
